OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Error" : "Greška",
    "Help" : "Pomoć",
    "Today" : "Danas",
    "Yesterday" : "Jučer",
    "Rename" : "Preimenuj",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Edit" : "Izmjeni",
    "Tasks" : "Zadaci"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
